<html>
<head>
<link rel="stylesheet" href="layersmenu.css" type="text/css">
<title>Dynamic JavaScript Layers Menu</title>

<? include ("layersmenu-header.inc.php"); ?>

</head>

<body bgcolor="#ffffff" marginheight=0 marginwidth=0 topmargin=0 leftmargin=0>
<table border=0 cellpadding=8 cellspacing=0 width="100%">
<tr valign=top>
<td class=verbarleft width="20%" align=center nowrap>
<br>
<?=$firstleveltable?>
<br>
</td>
<td class=label>Corpo della pagina</td>
</tr>
</table>

<? include ("layersmenu-footer.inc.php"); ?>

</body>
</html>
